#' Functions that are used internally in the main Multiphase Function
#'
#' @param formula Regression formula y ~ x + z
#' @param data Dataset in matrix format, containing all fully observed and partially observed variables
#' @param counts Count the number of repeated observations. Default is NULL.
#' @param always1 If a subject has probability 1 of being selected for further analysis, always1 should be TRUE. Otherwise, it should be FALSE. Default is NULL, meaning that there is no imposition on the selection probabilities.
#' @keywords cats
#' @export
#' @examples
#' model.apply()

model.apply = function(formula,data,counts=NULL,always1=NULL){
  mf <- call <- match.call()
  mf[[1]] <- as.name("model.frame")
  names(mf)[1] <- "model"
  mf$na.action = as.name("na.keep")
  mf <- eval(mf[c("model","formula","data","counts","always1","na.action")], sys.frame(sys.parent()))
  Terms <- attr(mf,"terms")
  X <- model.matrix(Terms,mf)
  if(!is.matrix(X)) X <- matrix(X)
  counts <- model.extract(mf, counts)
  always1 <- model.extract(mf, always1)
  y <- model.extract(mf,response)
  list(y=y,X=X,counts=counts,always1=always1,Terms=Terms)
}
na.keep = function(x) x

empcov = function(x, y=NULL, nreps = rep(1, nrow(x)),center=TRUE)
{
    x=as.matrix(x); nreps=as.vector(nreps); if (!is.null(y)) y=as.matrix(y)
    if (length(nreps) != nrow(x)) stop("x, nreps length  mismatch")

    n = sum(nreps)
    xmean = numeric(ncol(x)); if (!is.null(y)) ymean = numeric(ncol(y))
    if (center){
        xmean = colSums(x*nreps, na.rm = FALSE)/n
        if (!is.null(y)) ymean = colSums(y*nreps, na.rm = FALSE)/n
    }
    xdiff = x - outer(rep(1, nrow(x)), xmean)
    if (is.null(y)) ydiff=xdiff
    else ydiff =y - outer(rep(1, nrow(y)), ymean)
    r.nreps = sqrt(nreps)
    SS = t(xdiff*r.nreps) %*% (ydiff*r.nreps)
    cov = SS/(n-1)
    list(cov=cov,SS=SS,n=n)
}

cover = function(thetas,ses,theta.true){
    cin=as.numeric(0,ncol(thetas))
   for (j in (1:ncol(thetas))) {
       diffs <- (thetas[,j]-theta.true[j])/ses[,j]
       cin[j] <- length(diffs[abs(diffs) < 1.96])/nrow(thetas)
    }
    cin
}