% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MultiphaseFunction.R
\name{func}
\alias{func}
\title{Two and three-phase regression for discrete outcome}
\usage{
func(regformula, desnformula1, desnformula2 = NULL, desnformula3 = NULL,
  data, method = "offset", addStilde = FALSE, niter = 25, tol = 1e-06,
  maxstepprop = 0.1, print.iters = FALSE)
}
\arguments{
\item{regformula}{Regression formula: cc ~ x1 + x2}

\item{desnformula1}{Regression model for the first selection probability.}

\item{desnformula2}{Regression model for the second selection probability.}

\item{data}{Dataset in matrix format, containing all fully observed (outcome 'cc' and 'cheap' variables) and partially observed variables. See example on how to write the dataset.}

\item{method}{Either 'offset', if the conditional maximum likelihood approach is to be used, or 'weighted', if the Horvitz-Thompson estimator is of interest.}

\item{addStilde}{TRUE, if the joint estimation method is selected, FALSE otherwise.}

\item{niter}{Default is 1. If addStilde = TRUE, niter must be changed to some value larger than 1.}

\item{tol}{Maximum tolerance for Newton-Raphson iteration.}

\item{maxstepprop}{Maximum step to be taken in the Newton-Raphson iteration.}

\item{print.iters}{Print steps, TRUE or FALSE}
}
\description{
Function that applies the Horvitz-Thompson, the conditional maximum likelihood and the joint modelling approaches, for both two and three-phase data. This is a first version of the function and accepts only a discrete outcome. Extensions are under implementation.
}
\examples{
N <- 15000; beta <- c(-3,1,.5)
x1 <- rnorm(N)
x2 <- rnorm(N)
x1d <- 1*(x1<0)
x2d <- 1*(x2<.5)
ptrue <- plogis(beta[1] + beta[2]*x1 + beta[3]*x2)
cc <- 1*(runif(N)<ptrue)

##Totals
Ny1d0 <- sum(cc==1 & x1d==0); Ny1d1 <- sum(cc==1 & x1d==1);
Ny0d1 <- sum(cc==0 & x1d==1); Ny0d0 <- sum(cc==0 & x1d==0)

## Sample sizes
nsamples <- c(ny1d0=400, ny1d1=100, ny0d0=400, ny0d1=400)

## Selection
ind <- 1:N
samp1 <- c(sample(ind[cc==1 & x1d==0], nsamples[1]), sample(ind[cc==1 & x1d==1], nsamples[2]),
           sample(ind[cc==0 & x1d==0], nsamples[3]), sample(ind[cc==0 & x1d==1], nsamples[4]))

Ntotals <- cbind(Ny1d0, Ny1d1, Ny0d0, Ny0d1)
names(nsamples) <- c("y1d0", "y1d1", "y0d0", "y0d1")

R1 <- rep(0,N); R1[samp1] <- 1

## Response
samp2_func <- function(n,yu,v1,v2){sample(ind[R1==1 & cc==yu & x1d==v1 & x2d==v2],n)}
samp2 <- c(samp2_func(50,0,0,0),samp2_func(50,0,0,1),samp2_func(50,0,1,0),samp2_func(50,0,1,1),
           samp2_func(50,1,0,0),samp2_func(50,1,0,1),samp2_func(25,1,1,0),samp2_func(25,1,1,1))
R2 <- rep(NA,N);R2[R1==1] <- 0
R2[samp2] <- 1
x2d[R1==0] <- NA

datcsv <- data.frame(R1=R1,R2=R2,cc=cc,x1=x1,x1d=x1d,x2=x2,x2d=x2d)

regformula <- cc~x1+x2
desnformula1 <- R1~cc*x1d
desnformula2 <- R2~cc*x1d*x2d + cc*x1

out <- func(regformula, desnformula1, desnformula2, desnformula3=NULL, data=datcsv, method="offset", addStilde=TRUE, niter=25)
}
\keyword{Horvitz-Thompson,}
\keyword{Two-phase}
\keyword{conditional}
\keyword{likelihood,}
\keyword{maximum}
\keyword{sampling}
